==> RAthena_1.7.0.tar.gz: RAthena/tests/testthat/test-work-groups.R <==
context("Athena Work Groups")

# NOTE System variable format returned for Unit tests:
# Sys.getenv("rathena_arn"): "arn:aws:sts::123456789012:assumed-role/role_name/role_session_name"
# Sys.getenv("rathena_s3_query"): "s3://path/to/query/bucket/"
# Sys.getenv("rathena_s3_tbl"): "s3://path/to/bucket/"

test_that("Create and Delete Athena Work Groups",{
  skip_if_no_boto()
  skip_if_no_env()
  # Test connection is using AWS CLI to set profile_name 
  con <- dbConnect(RAthena::athena(),
                   profile_name = "rathena",
                   s3_staging_dir = Sys.getenv("rathena_s3_query"))
  
  output1 <- list_work_groups(con)
  work_groups1 <- sapply(output1, function(x) x$Name)
  
  create_work_group(con, "demo_work_group", description = "This is a demo work group",
                    tags = tag_options(key= "demo_work_group", value = "demo_01"))
  
  output2 <- list_work_groups(con)
  work_groups2 <- sapply(output2, function(x) x$Name)
  
  meta_data1 <- get_work_group(con, "demo_work_group")$Description
  update_work_group(con, "demo_work_group", description = "This is a demo work group update")
  meta_data2 <- get_work_group(con, "demo_work_group")$Description
  
  delete_work_group(con, "demo_work_group")
  
  output3 <- list_work_groups(con)
  work_groups3 <- sapply(output3, function(x) x$Name)
  
  dbDisconnect(con)
  
  expect_equal(any(grepl("demo_work_group", output1)), FALSE)
  expect_equal(any(grepl("demo_work_group", output2)), TRUE)
  expect_equal(any(grepl("demo_work_group", output3)), FALSE)
  expect_equal(meta_data1, "This is a demo work group")
  expect_equal(meta_data2, "This is a demo work group update")
})

==> RAthena_2.6.3.tar.gz: RAthena/tests/testthat/test-work-groups.R <==
context("Athena Work Groups")

# NOTE System variable format returned for Unit tests:
# Sys.getenv("rathena_arn"): "arn:aws:sts::123456789012:assumed-role/role_name/role_session_name"
# Sys.getenv("rathena_s3_query"): "s3://path/to/query/bucket/"
# Sys.getenv("rathena_s3_tbl"): "s3://path/to/bucket/"

test_that("Create and Delete Athena Work Groups",{
  skip_if_no_boto()
  skip_if_no_env()
  # Test connection is using AWS CLI to set profile_name 
  con <- dbConnect(RAthena::athena(),
                   s3_staging_dir = Sys.getenv("rathena_s3_query"))
  
  output1 <- list_work_groups(con)
  work_groups1 <- sapply(output1, function(x) x$Name)
  
  create_work_group(con, "demo_work_group", description = "This is a demo work group",
                    tags = tag_options(key= "demo_work_group", value = "demo_01"))
  
  output2 <- list_work_groups(con)
  work_groups2 <- sapply(output2, function(x) x$Name)
  
  meta_data1 <- get_work_group(con, "demo_work_group")$Description
  update_work_group(con, "demo_work_group", description = "This is a demo work group update")
  meta_data2 <- get_work_group(con, "demo_work_group")$Description
  
  delete_work_group(con, "demo_work_group")
  
  output3 <- list_work_groups(con)
  work_groups3 <- sapply(output3, function(x) x$Name)
  
  dbDisconnect(con)
  
  
  expect_error(create_work_group(con, "demo_work_group", description = "This is a demo work group",
                                 tags = tag_options(key= "demo_work_group", value = "demo_01")))
  expect_error(delete_work_group(con, "demo_work_group"))
  expect_error(list_work_groups(con))
  expect_error(get_work_group(con))
  expect_error(update_work_group(con, "demo_work_group", 
                                 description = "This is a demo work group update"))
  expect_equal(any(grepl("demo_work_group", output1)), FALSE)
  expect_equal(any(grepl("demo_work_group", output2)), TRUE)
  expect_equal(any(grepl("demo_work_group", output3)), FALSE)
  expect_equal(meta_data1, "This is a demo work group")
  expect_equal(meta_data2, "This is a demo work group update")
})
